"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.installConfigDeps = installConfigDeps;
const path_1 = __importDefault(require("path"));
const get_npm_tarball_url_1 = __importDefault(require("get-npm-tarball-url"));
const error_1 = require("@pnpm/error");
const pick_registry_for_package_1 = require("@pnpm/pick-registry-for-package");
const read_modules_dir_1 = require("@pnpm/read-modules-dir");
const rimraf_1 = __importDefault(require("@zkochan/rimraf"));
const read_package_json_1 = require("@pnpm/read-package-json");
async function installConfigDeps(configDeps, opts) {
    const configModulesDir = path_1.default.join(opts.rootDir, 'node_modules/.pnpm-config');
    const existingConfigDeps = await (0, read_modules_dir_1.readModulesDir)(configModulesDir) ?? [];
    await Promise.all(existingConfigDeps.map(async (existingConfigDep) => {
        if (!configDeps[existingConfigDep]) {
            await (0, rimraf_1.default)(path_1.default.join(configModulesDir, existingConfigDep));
        }
    }));
    await Promise.all(Object.entries(configDeps).map(async ([pkgName, pkgSpec]) => {
        const configDepPath = path_1.default.join(configModulesDir, pkgName);
        const sepIndex = pkgSpec.indexOf('+');
        if (sepIndex === -1) {
            throw new error_1.PnpmError('CONFIG_DEP_NO_INTEGRITY', `Your config dependency called "${pkgName}" at "pnpm.configDependencies" doesn't have an integrity checksum`, {
                hint: `All config dependencies should have their integrity checksum inlined in the version specifier. For example:

{
  "pnpm": {
    "configDependencies": {
      "my-config": "1.0.0+sha512-Xg0tn4HcfTijTwfDwYlvVCl43V6h4KyVVX2aEm4qdO/PC6L2YvzLHFdmxhoeSA3eslcE6+ZVXHgWwopXYLNq4Q=="
    },
  }
}`,
            });
        }
        const version = pkgSpec.substring(0, sepIndex);
        const integrity = pkgSpec.substring(sepIndex + 1);
        if (existingConfigDeps.includes(pkgName)) {
            const configDepPkgJson = await (0, read_package_json_1.safeReadPackageJsonFromDir)(configDepPath);
            if (configDepPkgJson == null || configDepPkgJson.name !== pkgName || configDepPkgJson.version !== version) {
                await (0, rimraf_1.default)(configDepPath);
            }
        }
        const registry = (0, pick_registry_for_package_1.pickRegistryForPackage)(opts.registries, pkgName);
        const { fetching } = await opts.store.fetchPackage({
            force: true,
            lockfileDir: opts.rootDir,
            pkg: {
                id: `${pkgName}@${version}`,
                resolution: {
                    tarball: (0, get_npm_tarball_url_1.default)(pkgName, version, { registry }),
                    integrity,
                },
            },
        });
        const { files: filesResponse } = await fetching();
        await opts.store.importPackage(configDepPath, {
            force: true,
            requiresBuild: false,
            filesResponse,
        });
    }));
}
//# sourceMappingURL=installConfigDeps.js.map